==> ejc-quality-impl-3.0.0-20240626.011032-54-sources.jar: com/ejianc/business/quality/entity/NonConformityEntity.java <==
package com.ejianc.business.quality.entity;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;


/**
 * @Author: LCL
 * @Date: 2024/5/14 下午4:03
 * @Description: 内部审核-不符合项
 */
@Data
@AllArgsConstructor
@NoArgsConstructor
@EqualsAndHashCode(callSuper = true)
@TableName("ejc_quality_non_conformity")
public class NonConformityEntity extends BaseEntity {
    /**
     * 分类(本部、分子公司、项目)
     *
     * @see com.ejianc.business.quality.enums.QualityTypeEnum
     */
    @TableField(value = "type")
    private String type;

    /**
     * 不符合项分类(观察项、NCR)
     */
    @TableField(value = "conformity_type")
    private String conformityType;

    /**
     * 不符合事实名称
     */
    @TableField(value = "facts_name")
    private String factsName;

    /**
     * 不符合事实url
     */
    @TableField(value = "facts")
    private String facts;

    /**
     * 不符合标准号(NCR)
     */
    @TableField(value = "bfhbzh")
    private String bfhbzh;

    /**
     * 管理类型(观察项)
     *
     * @see com.ejianc.business.quality.enums.NonConformityTypeEnum
     */
    @TableField(value = "gllx")
    private String gllx;

    /**
     * 归属体系
     *
     * @see com.ejianc.business.quality.enums.ManagementSystemEnum
     */
    @TableField(value = "gstx")
    private String gstx;

    /**
     * 编制人账号
     */
    @TableField(value = "prepared_user_code")
    private String preparedUserCode;

    /**
     * 所属项目部Id
     */
    @TableField(value = "org_id")
    private Long orgId;

    /**
     * 所属项目部名称
     */
    @TableField(value = "org_name")
    private String orgName;

    /**
     * 项目部上级组织Id
     */
    @TableField(value = "parent_org_id")
    private Long parentOrgId;

    /**
     * 项目部上级组织名称
     */
    @TableField(value = "parent_org_name")
    private String parentOrgName;
}

==> ejc-quality-impl-3.0.0-20240723.012129-57-sources.jar: com/ejianc/business/quality/entity/NonConformityEntity.java <==
package com.ejianc.business.quality.entity;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.NoArgsConstructor;


/**
 * @Author: LCL
 * @Date: 2024/5/14 下午4:03
 * @Description: 内部审核-不符合项
 */
@Data
@AllArgsConstructor
@NoArgsConstructor
@EqualsAndHashCode(callSuper = true)
@TableName("ejc_quality_non_conformity")
public class NonConformityEntity extends BaseEntity {
    /**
     * 创建者姓名
     */
    @TableField(value = "create_user_name")
    private String createUserName;
    /**
     * 更新着姓名
     */
    @TableField(value = "update_user_name")
    private String updateUserName;
    /**
     * 分类(本部、分子公司、项目)
     *
     * @see com.ejianc.business.quality.enums.QualityTypeEnum
     */
    @TableField(value = "type")
    private String type;

    /**
     * 不符合项分类(观察项、NCR)
     */
    @TableField(value = "conformity_type")
    private String conformityType;

    /**
     * 不符合事实名称
     */
    @TableField(value = "facts_name")
    private String factsName;

    /**
     * 不符合事实url
     */
    @TableField(value = "facts")
    private String facts;

    /**
     * 不符合标准号(NCR)
     */
    @TableField(value = "bfhbzh")
    private String bfhbzh;

    /**
     * 管理类型(观察项)
     *
     * @see com.ejianc.business.quality.enums.NonConformityTypeEnum
     */
    @TableField(value = "gllx")
    private String gllx;

    /**
     * 归属体系
     *
     * @see com.ejianc.business.quality.enums.ManagementSystemEnum
     */
    @TableField(value = "gstx")
    private String gstx;

    /**
     * 编制人账号
     */
    @TableField(value = "prepared_user_code")
    private String preparedUserCode;

    /**
     * 所属项目部Id
     */
    @TableField(value = "org_id")
    private Long orgId;

    /**
     * 所属项目部名称
     */
    @TableField(value = "org_name")
    private String orgName;

    /**
     * 项目部上级组织Id
     */
    @TableField(value = "parent_org_id")
    private Long parentOrgId;

    /**
     * 项目部上级组织名称
     */
    @TableField(value = "parent_org_name")
    private String parentOrgName;
}
